==> haskell-summoner-tui-2.0.1.1-718-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-DNdUy2srTG5AHHUpVAJAUX
key:                  summoner-tui-2.0.1.1-DNdUy2srTG5AHHUpVAJAUX
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  354beeb017726ea21d578520a4edb46b
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.4.8/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/summoner-tui-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-DNdUy2srTG5AHHUpVAJAUX
depends:
    base-4.17.2.1 relude-1.2.2.2-4QKJ12AjjadGiCoCuzizMH
    brick-0.71.1-26wLhjlmARPDXjpPf7Fuoe
    colourista-0.1.0.2-H7RKz6j0wA4Iuics6WxGGM directory-1.3.7.1
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    summoner-2.0.1.1-5RzeiuGOcTELRWheu5sWI2
    validation-selective-0.2.0.0-KNcNnqq7Psg3gF5VFYAuSu
    vty-5.39-3aZQKK7jBsAJsdOpYca1A2

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-summoner-tui-2.0.1.1-741-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-summoner-tui.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 summoner-tui
version:              2.0.1.1
visibility:           public
id:                   summoner-tui-2.0.1.1-Es2kp5kGDQOKhDYQ2oXsyz
key:                  summoner-tui-2.0.1.1-Es2kp5kGDQOKhDYQ2oXsyz
license:              MPL-2.0
copyright:            2018-2020 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
stability:            experimental
homepage:             https://github.com/kowainik/summoner
synopsis:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.

description:
    Tool for scaffolding fully configured batteries-included production-level Haskell projects using TUI.
    See [README.md](https://github.com/kowainik/summoner#-summoner) for details.

category:             TUI, TUI Tool, Development
abi:                  c4c7494d682826a1b9550a4835ad715a
exposed:              True
exposed-modules:
    Summoner.Tui Summoner.Tui.Field Summoner.Tui.Form
    Summoner.Tui.GroupBorder Summoner.Tui.Kit Summoner.Tui.Validation
    Summoner.Tui.Widget

hidden-modules:       Paths_summoner_tui
import-dirs:          /usr/lib/ghc-9.4.8/site-local/summoner-tui-2.0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/summoner-tui-2.0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/summoner-tui-2.0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-summoner-tui
hs-libraries:         HSsummoner-tui-2.0.1.1-Es2kp5kGDQOKhDYQ2oXsyz
depends:
    base-4.17.2.1 relude-1.2.2.2-Bl8jl1Mjkjo7ysD7Vb9Fux
    brick-0.71.1-DYiq6SVXbc1FODMwgKfgWM
    colourista-0.1.0.2-Lo9Z9wdKunE9ASTA6VvG91 directory-1.3.7.1
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    summoner-2.0.1.1-D9H2GcKjLl1Ipab1HQWm3u
    validation-selective-0.2.0.0-CbJsyvwdVL05TZFQ8E5cjs
    vty-5.39-IzpzW9ooAXyC6UedcWj3fC

haddock-interfaces:
    /usr/share/doc/haskell-summoner-tui/html/summoner-tui.haddock

haddock-html:         /usr/share/doc/haskell-summoner-tui/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
